import Router from './Router';
import Response from './Response';
import Controller from './Controller';

import http from 'http';
import logger from './logger';

export {
  Router,
  Response,
  Controller as BaseController,
};

class App {

  port = 6060;
  prefix = '';
  base;

  run() {
    let routes, controllers, port;
    let base = this.base = `${process.cwd()}/${this.prefix}`;

    controllers = `${base}/controllers`;

    try {
      routes = require(`${base}/routes`).default;
    } catch(e) {
      try {
        routes = require(`${base}/routes`);
      } catch(e) {
        throw new Error('app must have the "routes" directory with index file near her')
      }
    }


    try {
      port = require(`${base}/config`).port;
    } catch(e) {}

    Router.setControllersPath(controllers);

    return http.createServer((req, res) => {
      logger(req, res);

      Router.route(req, res);
    }).listen(port);
  }

  set(key, val) {
    this[key] = val;
  }

  get(key) {
    if (this[key]) return this[key];
    else return undefined;
  }

}

export default new App();
