import isArray from '../array/isArray';
import isString from '../string/isString';
import isObject from './isObject';

/**
 *
 * @name omit
 * @param data {object}
 * @param rules {string} or {array}
 * @returns {array}
 *
 * @example omit({ user: 'zxc', pass: 'secret' }, 'pass') // returns ['zxc']
 * @example omit({ user: 'zxc', pass: 'secret' }, ['pass']) // returns ['zxc']
 *
 * @description if element not found, omit returns @param data
 * @copyright Vladimir Sentiurin 2017
 */

export default (data, rules) => {
  if (isObject(data)) {
    let keys = Object.keys(data);

    if (isArray(rules)) {
      for (let i = 0; i < keys.length; i++) {
        rules.map(rule => delete data[rule]);
      }
    } else if (isString(rules)) {
      delete data[rules];
    }

    return data;
  } else {
    throw new Error(`first argument "${data}" must be object in omit function`);
  }
};
